@@ -11,6 +11,17 @@ def _seemsValidRawArticle(soup, text_limit = 500):
 		return False
 	return not not soup.find('img')
 
+def getMatters(soup):
+	main = soup.find("div", class_ = "u-content")
+	item = soup.find("div", id = "__next")
+	if not item:
+		return main
+	item = item.findNext('p')
+	while item:
+		main.insert(len(main.contents), item)
+		item = item.findNext('p')
+	return main
+
 def _getInnerArticle_(soup, domain):	
 	applicators = [
 		lambda x: x.find("article"),
@@ -24,7 +35,6 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "article"),
 		lambda x: x.find("div", class_ = "field-name-body"),
 		lambda x: x.find("div", class_ = "content"),
-		lambda x: x.find("div", class_ = "u-content"),
 		lambda x: x.find("div", class_ = "RichContent-inner"),
 		lambda x: x.find("div", class_ = "entry-content"),
 		lambda x: x.find("div", class_ = 'pf-content'),
@@ -42,7 +52,6 @@ def _getInnerArticle_(soup, domain):
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
-		'matters': [lambda x: x.find("div", class_ = "u-content")],
 		'douban': [
 			lambda x: x.find("div", {"id" : "link-report"}),
 			lambda x: x.find("div", class_ = "note"),
@@ -65,6 +74,7 @@ def _getInnerArticle_(soup, domain):
 		'equalityrights.hku.hk': [lambda x: x.find("article")],
 		'biede.com': [lambda x: x.find("div", class_ = 'lay'),],
 		'www.thewechatproject.org': [lambda x: x.find("div", class_ = 'post-content__body'),],
+		'freewechat.com': [lambda x: x.find("div", class_ = 'rich_media_content'),],
 	}
 	is_short = matchKey(soup.text, SHORT_ARTICLE)
 	text_limit = 150 if is_short else 500
@@ -72,6 +82,8 @@ def _getInnerArticle_(soup, domain):
 		candidate = applicator(soup)
 		if _seemsValidRawArticle(candidate, text_limit = text_limit):
 			soup = candidate
+	if 'matters.news' in domain:
+		return getMatters(soup)
 	for d, applicators in domain_specific_applicators.items():
 		if d in domain:
 			for applicator in applicators:
