@@ -53,6 +53,8 @@ DIV_AD_WORDS = [
 ]
 
 P_AD_WORDS = [
+	'別忘了給點支持與讚賞，讓我知道創作的路上有你陪伴。',
+	'一鍵登入，即可加入全球最優質中文創作社區',
 	'The Times is committed', 
 	'Follow The New York Times',
 	'Love HuffPost',
